# <img src='https://rawgithub.com/FortAwesome/Font-Awesome/master/svgs/solid/spinner.svg' card_color='#22a7f0' width='50' height='50' style='vertical-align:bottom'/> Application Launcher
Application Launcher

## About 
Launch applications on the Linux desktop

The standard directories will be scanned for [.desktop files](https://wiki.archlinux.org/title/desktop_entries), application names and execution commands will be parsed from there

Scanned folders:
 - /usr/share/applications/
 - /usr/local/share/applications/
 - ~/.local/share/applications/

## Examples 
* "Open Volume Control"
* "Launch Firefox"

## Category
**Productivity**

## Tags
#desktop
#desktop-launch
#desktop-launcher
